Welcome to Joyous's documentation
=================================

Joyous is a reusable calendar application for Wagtail.  *May all your events be joyous.*


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   tutorials/index
   topics/index
   reference/index
   releases/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
